@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Draw Guitar Chord Diagrams
 
-our $VERSION = '0.0400';
+our $VERSION = '0.0401';
 
 use Moo;
 use strictures 2;
@@ -233,21 +233,26 @@ Music::GuitarChordDiagram - Draw Guitar Chord Diagrams
 
 =head1 VERSION
 
-version 0.0400
+version 0.0401
 
 =head1 SYNOPSIS
 
   use Music::GuitarChordDiagram;
 
   my $dia = Music::GuitarChordDiagram->new(
-    chord    => 'x02220',
-    position => 1,
-    strings  => 6,
-    frets    => 5,
-    size     => 30,
-    outfile  => 'chord-diagram',
+    chord => 'x02220',
+    font  => '/path/to/TTF/font.ttf',
+  );
+
+  $dia = Music::GuitarChordDiagram->new(
+    chord    => '4442',
+    position => 3,
+    strings  => 4,
+    frets    => 6,
+    size     => 25,
+    outfile  => 'ukulele-chord',
     font     => '/path/to/TTF/font.ttf',
-    tuning   => [qw/E B G D A E/],
+    tuning   => [qw/A E C G/],
     verbose  => 1,
   );
 
@@ -255,8 +260,8 @@ version 0.0400
 
 =head1 DESCRIPTION
 
-A C<Music::GuitarChordDiagram> object draws guitar chord diagrams including neck
-position and chord name annotations.
+A C<Music::GuitarChordDiagram> object draws fretboard chord diagrams including
+neck position and chord name annotations.
 
 =for html <br><img src="https://raw.githubusercontent.com/ology/Music-GuitarChordDiagram/master/chord-diagram.png"><br>
 
@@ -267,36 +272,35 @@ position and chord name annotations.
   $dia->chord('xx0232');
   $chord = $dia->chord;
 
-A guitar chord given in string format, where non-zero digits represent
-frets, C<x> (or C<X>) indicates a muted string and C<0> (or C<o> or C<O>)
-indicates an open string.  The order of the strings is C<654321> from lowest to
-highest.
+A chord given in string format, where non-zero digits represent frets, C<x> (or
+C<X>) indicates a muted string and C<0> (or C<o> or C<O>) indicates an open
+string.  The default order of the strings is C<654321> from lowest to highest.
 
 Examples:
 
-  c: x32010
-  d: xxO232
-  e: 022100
-  f: xx3211
-  g: 210002
-  a: x02220
-  b: x24442
+  C: x32010
+  D: xx0232
+  E: 022100
+  F: xx3211
+  G: 320003
+  A: x02220
+  B: x24442
  
-  cm: xx5543
-  dm: xx0231
-  em: 022000
-  fm: xx3111
-  gm: xx5333
-  am: x02210
-  bm: x24432
+  Cm: xx5543
+  Dm: xx0231
+  Em: 022000
+  Fm: xx3111
+  Gm: xx5333
+  Am: x02210
+  Bm: x24432
  
-  c7: x32310
-  d7: xx0212
-  e7: 020100
-  f7: xx1211
-  g7: 320001
-  a7: x02020
-  b7: x21202
+  C7: x32310
+  D7: xx0212
+  E7: 020100
+  F7: xx1211
+  G7: 320001
+  A7: x02020
+  B7: x21202
 
 =head2 position
 
